@@ -195,8 +195,21 @@ dialog_cb (BonoboUIComponent *component,
 		return;
 	}
 
+	/* This is the old way of calling things, we try this just in case
+	 * we're in a mixed-version enviroment. It has to be tried first, 
+	 * because the new command doesn't fail in a way useful to
+	 * gdk_spawn_command_line_on_screen and its error parameter. */
 	gdk_spawn_command_line_on_screen (gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)),
-			"gnome-accessibility-keyboard-properties", &error);
+					  "gnome-accessibility-keyboard-properties", 
+					  &error);
+
+	if (error != NULL) {
+		g_error_free (error);
+		error = NULL;
+	        gdk_spawn_command_line_on_screen (gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)),
+						  "gnome-keyboard-properties --a11y", 
+						  &error);
+	}
 
 	if (error != NULL) {
 		GtkWidget *dialog = 
@@ -380,8 +393,10 @@ accessx_status_applet_get_glyph_pixbuf (AccessxStatusApplet *sapplet,
 	pango_layout_set_text (layout, glyphstring, -1);
 	gc = gdk_gc_new (GDK_DRAWABLE (pixmap));
 	cmap = gdk_drawable_get_colormap (GDK_DRAWABLE (pixmap));
-	if (!cmap) cmap = gdk_colormap_new (visual, FALSE);
-	else g_object_ref (cmap);
+	if (!cmap) {
+	  cmap = gdk_colormap_new (visual, FALSE);
+	  gdk_drawable_set_colormap (GDK_DRAWABLE (pixmap), cmap);
+	} else g_object_ref (cmap);
 	gdk_colormap_alloc_color (cmap, fg, FALSE, TRUE);
 	gdk_colormap_alloc_color (cmap, bg, FALSE, TRUE);
 	gdk_gc_set_foreground (gc, bg);
