@@ -21,9 +21,21 @@
 
 #include <config.h>
 #include <string.h>
-#include <gnome.h>
-#include <panel-applet.h>
+#include <stdlib.h>
+
 #include <gdk/gdkkeysyms.h>
+#include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkentry.h>
+#include <gtk/gtkfilechooser.h>
+#include <gtk/gtkfilechooserdialog.h>
+#include <gtk/gtkframe.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtktreeselection.h>
+#include <gtk/gtktreeview.h>
+
+#include <panel-applet.h>
 
 #include "mini-commander_applet.h"
 #include "command_line.h"
@@ -42,11 +54,14 @@ static int history_position = MC_HISTORY_LIST_LENGTH;
 static gchar *browsed_folder = NULL;
 
 static gboolean
-button_press_cb (GtkEntry   *entry,
-		 GdkEventKey *event,
-		 MCData      *mc)
+button_press_cb (GtkEntry       *entry,
+		 GdkEventButton *event,
+		 MCData         *mc)
 {
     const gchar *str;
+
+    panel_applet_request_focus (mc->applet, event->time);
+
     if (mc->error) { 
 	   mc->error = FALSE; 
 	   str = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
@@ -192,7 +207,6 @@ history_popup_clicked_inside_cb(GtkWidget *widget, gpointer data)
 static gboolean
 history_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
-   
     if (event->keyval == GDK_Escape) {
         gdk_pointer_ungrab(GDK_CURRENT_TIME);
         gdk_keyboard_ungrab(GDK_CURRENT_TIME);
@@ -235,7 +249,9 @@ history_list_key_press_cb (GtkWidget   *widget,
         mc_exec_command (mc, command);
         g_free (command);
         gtk_widget_destroy(GTK_WIDGET(widget->parent->parent->parent));
-        break;
+
+	return TRUE;
+
     default:
         break;
     }
@@ -263,7 +279,10 @@ history_list_button_press_cb (GtkWidget      *widget,
         mc_exec_command(mc, command);
         g_free (command);
         gtk_widget_destroy(GTK_WIDGET(widget->parent->parent->parent));
+
+	return TRUE;
     }
+
     return FALSE;
 }
 
@@ -294,6 +313,7 @@ mc_show_history (GtkWidget *widget,
      gtk_window_set_screen (GTK_WINDOW (window),
 			    gtk_widget_get_screen (GTK_WIDGET (mc->applet)));
      gtk_window_set_policy(GTK_WINDOW(window), 0, 0, 1);
+     gtk_window_set_type_hint(GTK_WINDOW(window), GDK_WINDOW_TYPE_HINT_COMBO);
      /* cb */
      g_signal_connect_after(GTK_OBJECT(window),
 			      "button_press_event",
@@ -496,7 +516,13 @@ mc_create_command_entry (MCData *mc)
 		      G_CALLBACK (button_press_cb), mc);
 
     if (!mc->preferences.show_default_theme)
-        mc_command_update_entry_color (mc); 
+    {
+	    gtk_widget_set_name (mc->entry, "minicommander-applet-entry");
+	    mc_command_update_entry_color (mc); 
+    }
+    else
+	    gtk_widget_set_name (mc->entry,
+			    "minicommander-applet-entry-default");
 
     mc_command_update_entry_size (mc);
 
@@ -510,11 +536,26 @@ mc_command_update_entry_color (MCData *mc)
 {
     GdkColor fg;
     GdkColor bg;
+    char *rc_string;
 
     fg.red   = mc->preferences.cmd_line_color_fg_r;
     fg.green = mc->preferences.cmd_line_color_fg_g;
     fg.blue  = mc->preferences.cmd_line_color_fg_b;
 
+    /* FIXME: wish we had an API for this, see bug #79585 */
+    rc_string = g_strdup_printf (
+		    "\n"
+		    " style \"minicommander-applet-entry-style\"\n"
+		    " {\n"
+		    "  GtkWidget::cursor-color=\"#%04x%04x%04x\"\n"
+		    " }\n"
+		    " widget \"*.minicommander-applet-entry\" "
+		    "style \"minicommander-applet-entry-style\"\n"
+		    "\n",
+		    fg.red, fg.green, fg.blue);
+    gtk_rc_parse_string (rc_string);
+    g_free (rc_string);
+
     gtk_widget_modify_text (mc->entry, GTK_STATE_NORMAL, &fg);
     gtk_widget_modify_text (mc->entry, GTK_STATE_PRELIGHT, &fg);
    
