@@ -27,8 +27,6 @@
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkrange.h>
 #include <gtk/gtkwindow.h>
-#include <gst/gst.h>
-#include <gst/mixer/mixer.h>
 
 G_BEGIN_DECLS
 
@@ -42,7 +40,7 @@ G_BEGIN_DECLS
 			    GnomeAppletAppletAppletDockClass))
 #define GNOME_VOLUME_APPLET_IS_DOCK(obj) \
   (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_VOLUME_APPLET_TYPE_DOCK))
-#define GNOME_VOLUME_APPLET_IS_DOCK_CLASS(obj) \
+#define GNOME_VOLUME_APPLET_IS_DOCK_CLASS(klass) \
   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_VOLUME_APPLET_TYPE_DOCK))
 
 typedef struct _GnomeVolumeAppletDock {
@@ -64,10 +62,11 @@ typedef struct _GnomeVolumeAppletDockClass {
   GtkWindowClass klass;
 } GnomeVolumeAppletDockClass;
 
-GType		gnome_volume_applet_dock_get_type	(void);
-GtkWidget *	gnome_volume_applet_dock_new		(GtkOrientation orientation);
-void		gnome_volume_applet_dock_change		(GnomeVolumeAppletDock *dock,
-							 GtkAdjustment *adj);
+GType gnome_volume_applet_dock_get_type	(void);
+GtkWidget *gnome_volume_applet_dock_new (GtkOrientation orientation);
+void gnome_volume_applet_dock_change (GnomeVolumeAppletDock *dock,
+				      GtkAdjustment *adj);
+void gnome_volume_applet_dock_set_focus (GnomeVolumeAppletDock *dock);
 
 G_END_DECLS
 
