@@ -23,15 +23,14 @@
 #include <gdk/gdkscreen.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtkadjustment.h>
-#include <gtk/gtktooltips.h>
 #include <gtk/gtkwidget.h>
-#include <glade/glade-xml.h>
+#include <gtk/gtkbuilder.h>
 #include <panel-applet.h>
 #include <gconf/gconf-client.h>
-#include <glade/glade.h>
+
 
 #define GCONF_PATH	"/apps/stickynotes_applet"
-#define GLADE_PATH	GNOME_GLADEDIR "/stickynotes.glade"
+#define BUILDER_PATH	GTK_BUILDERDIR "/stickynotes.ui"
 #define XML_PATH	"/.gnome2/stickynotes_applet"
 #define ICON_PATH	STICKYNOTES_ICONDIR
 
@@ -44,7 +43,7 @@
 /* Global Sticky Notes instance */
 typedef struct
 {
-	GladeXML *prefs;		/* Preferences dialog GladeXML */
+	GtkBuilder *builder;		
 
 	GtkWidget *w_prefs;		/* The prefs dialog */
 	GtkAdjustment *w_prefs_width;
@@ -64,7 +63,8 @@ typedef struct
 	GdkPixbuf *icon_prelight;	/* Prelighted applet icon */
 
 	GConfClient *gconf;		/* GConf Client */
-	GtkTooltips *tooltips;		/* Tooltips */
+
+	guint last_timeout_data;
 } StickyNotes;
 
 /* Sticky Notes Icons */
@@ -81,7 +81,6 @@ typedef struct
 	GtkWidget *w_applet;		/* The applet */
 	GtkWidget *w_image;		/* The applet icon */
 
-	GtkWidget *about_dialog;	/* The applet it's about dialog */
 	GtkWidget *destroy_all_dialog;	/* The applet it's destroy all dialog */
 	
 	gboolean prelighted;		/* Whether applet is prelighted */
@@ -91,7 +90,6 @@ typedef struct
 	PanelAppletOrient panel_orient;
 	
 	GtkWidget *menu_tip;
-	GtkWidget *menu_show;
 } StickyNotesApplet;
 	
 typedef enum
